@@ -4,6 +4,7 @@ SGE_CLUSTER_NAME="starcluster"
 SGE_ROOT="/opt/sge6"
 SGE_QMASTER_PORT="63231"
 SGE_EXECD_PORT="63232"
+SGE_ENABLE_SMF="false"
 CELL_NAME="default"
 ADMIN_USER=""
 QMASTER_SPOOL_DIR="/opt/sge6/default/spool/qmaster"
@@ -22,7 +23,7 @@ SHELL_NAME="ssh"
 COPY_COMMAND="scp"
 DEFAULT_DOMAIN="none"
 ADMIN_MAIL="none@none.edu"
-ADD_TO_RC="false"
+ADD_TO_RC="true"
 SET_FILE_PERMS="true"
 RESCHEDULE_JOBS="wait"
 SCHEDD_CONF="1"
